# remirepo spec file for php-pecl-vld
#
# SPDX-FileCopyrightText:  Copyright 2013-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#

%{?scl:%scl_package php-pecl-vld}

%global pecl_name   vld
%global pie_vend    derickr
%global pie_proj    vld
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name    40-%{pecl_name}.ini
%global sources     %{pecl_name}-%{version}
%global _configure  ../%{sources}/configure

Summary:        Dump the internal representation of PHP scripts
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
License:        PHP-3.01
Version:        0.19.0
Release:        1%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 7.0
BuildRequires:  %{?scl_prefix}php-pear

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}                 = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})           = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa}   = %{version}
Provides:       %{?scl_prefix}php-pie(%{pie_vend}/%{pie_proj}) = %{version}
Provides:       %{?scl_prefix}php-%{pie_vend}-%{pie_proj}      = %{version}


%description
The Vulcan Logic Disassembler hooks into the Zend Engine and
dumps all the opcodes (execution units) of a script.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

sed -e '/LICENSE/s/role="doc"/role="src"/' -i package.xml

pushd %{sources}
#: Fix version
#sed -e 's/"0.16.0"/"%{version}"/' -i vld.c

: Check version
if ! grep -q '"%{version}"' vld.c; then
   : Error: Upstream extension version, expecting %{version}.
   exit 1
fi
popd

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Create configuration file
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so

;vld.active=0
;vld.skip_prepend=0
;vld.skip_append=0
;vld.execute=1
;vld.verbosity=1
;vld.format=0
;vld.col_sep="	"
;vld.save_dir="/tmp"
;vld.save_paths=0
;vld.dump_paths=1
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}
[ -f Makefile.global ] && GLOBAL=Makefile.global || GLOBAL=build/Makefile.global
sed -e 's/INSTALL_ROOT/DESTDIR/' -i $GLOBAL

cd ../NTS
%configure \
    --with-php-config=%{__phpconfig}
%make_build

%if %{with_zts}
cd ../ZTS
%configure \
    --with-php-config=%{__ztsphpconfig}
%make_build
%endif


%install
%{?dtsenable}

%make_install -C NTS

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%make_install -C ZTS

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
cd %{sources}
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
# Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=NTS/modules/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with_zts}
# Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=ZTS/modules/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'
%endif


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Wed Jul  2 2025 Remi Collet <remi@remirepo.net> - 0.19.0-1
- update to 0.19.0
- re-license spec file to CECILL-2.1

* Tue Sep 24 2024 Remi Collet <remi@remirepo.net> - 0.18.0-6
- rebuild for 8.4.0RC1

* Thu Aug 29 2024 Remi Collet <remi@remirepo.net> - 0.18.0-5
- add upstream patch for PHP 8.4.0beta4

* Thu Aug 22 2024 Remi Collet <remi@remirepo.net> - 0.18.0-4
- add minimal patch for 8.4.0beta3 from
  https://github.com/derickr/vld/pull/83

* Fri Jul 12 2024 Remi Collet <remi@remirepo.net> - 0.18.0-3
- add upstream patch for PHP 8.4

* Mon Sep  4 2023 Remi Collet <remi@remirepo.net> - 0.18.0-2
- build out of sources tree

* Fri Sep 16 2022 Remi Collet <remi@remirepo.net> - 0.18.0-1
- update to 0.18.0

* Thu Sep 15 2022 Remi Collet <remi@remirepo.net> - 0.17.2-2
- add upstream for PHP 8.2

* Tue Nov 30 2021 Remi Collet <remi@remirepo.net> - 0.17.2-1
- update to 0.17.2
- add patch for build warnings from
  https://github.com/derickr/vld/pull/72

* Mon Jan 11 2021 Remi Collet <remi@remirepo.net> - 0.17.1-1
- update to 0.17.1

* Tue Jan 14 2020 Remi Collet <remi@remirepo.net> - 0.17.0-1
- update to 0.17.0

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.16.0-3
- rebuild for 7.4.0RC1

* Wed May 29 2019 Remi Collet <remi@remirepo.net> - 0.16.0-2
- rebuild

* Wed May 29 2019 Remi Collet <remi@remirepo.net> - 0.16.0-1
- update to 0.16.0

* Tue Dec  4 2018 Remi Collet <remi@remirepo.net> - 0.15.0-1
- update to 0.15.0

* Fri Aug 24 2018 Remi Collet <remi@remirepo.net> - 0.15.0-0.14.20180814.8146d47
- refresh

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.15.0-0.13.20180514.1719df5
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 0.15.0-0.12.20180514.1719df5
- rebuild for 7.3.0alpha4 new ABI

* Mon Jul  2 2018 Remi Collet <remi@remirepo.net> - 0.15.0-0.11.20180514.1719df5
- update to 0.15.0-dev for PHP 7.3

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 0.14.0-2
- rebuild for PHP 7.2.0beta1 new API

* Mon Dec 19 2016 Remi Collet <remi@fedoraproject.org> - 0.14.0-1
- Update to 0.14.0

* Tue Mar  8 2016 Remi Collet <remi@fedoraproject.org> - 0.13.0-2
- adapt for F24
- fix license management

* Wed Dec 24 2014 Remi Collet <remi@fedoraproject.org> - 0.13.0-1.1
- Fedora 21 SCL mass rebuild

* Fri Nov 14 2014 Remi Collet <remi@fedoraproject.org> - 0.13.0-1
- Update to 0.13.0 (beta)

* Tue Aug 26 2014 Remi Collet <rcollet@redhat.com> - 0.12.0-6
- improve SCL build

* Thu Jun 26 2014 Remi Collet <remi@fedoraproject.org> - 0.12.0-5
- more upstream patches for PHP 5.6

* Thu Apr 17 2014 Remi Collet <remi@fedoraproject.org> - 0.12.0-4
- add numerical prefix to extension configuration file (php 5.6)

* Mon Mar 24 2014 Remi Collet <remi@fedoraproject.org> - 0.12.0-3
- allow SCL build

* Sun Mar 16 2014 Remi Collet <remi@fedoraproject.org> - 0.12.0-2
- install doc in pecl_docdir
- add missing License file (from github repo)
- apply upstream patch for PHP 5.6

* Wed Sep 25 2013 Remi Collet <remi@fedoraproject.org> - 0.12.0-1
- initial package
